#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 expiring-cache-map
version:              0.0.6.1
visibility:           public
id:                   expiring-cache-map-0.0.6.1-IEIKWTb5B2x8fyuApYjlUk
key:                  expiring-cache-map-0.0.6.1-IEIKWTb5B2x8fyuApYjlUk
license:              BSD-3-Clause
copyright:            (c) 2014 Edward L. Blake
maintainer:           edwardlblake@gmail.com
author:               Edward L. Blake
homepage:             https://github.com/elblake/expiring-cache-map
synopsis:             General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.

category:             Caching
abi:                  2d7b04678e1f4968168e586851f4ec80
exposed:              True
exposed-modules:
    Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/expiring-cache-map-0.0.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/expiring-cache-map-0.0.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/expiring-cache-map-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-expiring-cache-map
hs-libraries:         HSexpiring-cache-map-0.0.6.1-IEIKWTb5B2x8fyuApYjlUk
depends:
    base-4.18.2.1 containers-0.6.7
    hashable-1.4.7.0-KYRxVQLzygQHnYjqLKyJPN
    unordered-containers-0.2.21-5Z67IC6H036CG8YRUzTmvt

haddock-interfaces:
    /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock

haddock-html:         /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

